@@ -10,9 +10,14 @@ import logging
 import urllib
 
 # external imports
-import chainlib.eth.cli
+from chainlib.settings import ChainSettings
 from funga.eth.signer import EIP155Signer
 from funga.eth.keystore.dict import DictKeystore
+from chainlib.chain import ChainSpec
+from chainlib.jsonrpc import (
+        JSONRPCRequest,
+        IntSequenceGenerator,
+        )
 from hexathon import (
         add_0x,
         strip_0x,
@@ -22,10 +27,6 @@ from hexathon import (
 # local imports
 from chainlib.eth.address import to_checksum
 from chainlib.eth.connection import EthHTTPConnection
-from chainlib.jsonrpc import (
-        JSONRPCRequest,
-        IntSequenceGenerator,
-        )
 from chainlib.eth.nonce import (
         RPCNonceOracle,
         OverrideNonceOracle,
@@ -39,37 +40,60 @@ from chainlib.eth.tx import (
         raw,
         )
 from chainlib.eth.error import RevertEthException
-from chainlib.chain import ChainSpec
 from chainlib.eth.runnable.util import decode_for_puny_humans
 from chainlib.eth.jsonrpc import to_blockheight_param
+import chainlib.eth.cli
+from chainlib.eth.cli.arg import (
+        Arg,
+        ArgFlag,
+        process_args,
+        )
+from chainlib.eth.cli.config import (
+        Config,
+        process_config,
+        )
+from chainlib.eth.cli.log import process_log
+from chainlib.eth.settings import process_settings
 
-logging.basicConfig(level=logging.WARNING)
 logg = logging.getLogger()
 
 script_dir = os.path.dirname(os.path.realpath(__file__)) 
 config_dir = os.path.join(script_dir, '..', 'data', 'config')
 
-arg_flags = chainlib.eth.cli.argflag_std_read
-argparser = chainlib.eth.cli.ArgumentParser(arg_flags)
+
+def process_config_local(config, arg, args, flags):
+    config.add(args.ignore, '_IGNORE', False)
+    config.add(args.ignore_all, '_IGNORE_ALL', False)
+    config.add(args.hashes, '_HASH', False)
+    return config
+
+
+def process_settings_local(settings, config):
+    settings.set('HASH', config.get('_HASH'))
+    return settings
+
+
+arg_flags = ArgFlag()
+arg = Arg(arg_flags)
+flags = arg_flags.STD_READ
+
+argparser = chainlib.eth.cli.ArgumentParser()
+argparser = process_args(argparser, arg, flags)
 argparser.add_argument('--ignore', type=str, action='append', default=[], help='Ignore error from the given transaction')
 argparser.add_argument('--ignore-all', action='store_true', dest='ignore_all', help='Ignore errors from all transactions')
-argparser.add_positional('hashes', append=True, type=str, help='Transaction hashes to wait for')
+argparser.add_argument('hashes', nargs='*', type=str, help='Transaction hashes to wait for')
 args = argparser.parse_args()
-extra_args = {
-    'ignore': None,
-    'ignore_all': None,
-    'hashes': None,
-        }
-config = chainlib.eth.cli.Config.from_args(args, arg_flags, extra_args=extra_args, default_config_dir=config_dir)
 
-rpc = chainlib.eth.cli.Rpc()
-conn = rpc.connect_by_config(config)
+logg = process_log(args, logg)
 
-chain_spec = None
-try:
-    chain_spec = ChainSpec.from_chain_str(config.get('CHAIN_SPEC'))
-except AttributeError:
-    pass
+config = Config()
+config = process_config(config, arg, args, flags)
+config = process_config_local(config, arg, args, flags)
+logg.debug('config loaded:\n{}'.format(config))
+
+settings = ChainSettings()
+settings = process_settings(settings, config)
+logg.debug('settings loaded:\n{}'.format(settings))
 
 
 def main():
@@ -80,29 +104,30 @@ def main():
     for hsh in config.get('_IGNORE'):
         hashes_ignore.append(add_0x(hex_uniform(strip_0x(hsh))))
 
-    if len(config.get('_HASHES')) == 1:
+    if len(settings.get('HASH')) == 1:
+        hsh = settings.get('HASH')[0]
         try:
-            hsh = add_0x(hex_uniform(strip_0x(config.get('_HASHES')[0])))
             hashes_ready = [hsh]
         except ValueError:
             logg.debug('hash argument not a hash, will try it as a file name')
-            f = open(config.get('_HASHES')[0])
+            f = open(hsh)
             for hsh in f:
-                logg.debug('hshs {}'.format(hsh))
-                hashes_ready.append(add_0x(hex_uniform(strip_0x(hsh.rstrip()))))
+                hashes_ready.append(hsh)
             f.close()
     else:
-        for hsh in config.get('_HASHES'):
-            logg.debug('hsh {}'.format(hsh))
-            hashes_ready.append(add_0x(hex_uniform(strip_0x(hsh))))
+        for hsh in settings.get('HASH'):
+            if hsh in hashes_ready:
+                logg.debug('skipping duplicate hash {}'.format(hsh))
+                continue
+            hashes_ready.append(hsh)
             
     for hsh in hashes_ready:
-        logg.debug('processing transaction hash {}'.format(hsh))
+        logg.info('processing transaction hash {}'.format(hsh))
         try:
-            r = conn.wait(hsh)
+            r = settings.get('CONN').wait(hsh)
         except RevertEthException:
             if config.get('_IGNORE_ALL') or hsh in hashes_ignore:
-                logg.info('ignoring revert in transaction hash {}'.format(hsh))
+                logg.debug('ignoring revert in transaction hash {}'.format(hsh))
                 continue
             sys.stderr.write('revert in transaction hash {}\n'.format(hsh))
             sys.exit(1)
@@ -110,5 +135,3 @@ def main():
 
 if __name__ == '__main__':
     main()
-
-
