@@ -410,12 +410,14 @@ class TxFactory:
         txe = EIP155Transaction(tx, tx['nonce'], tx['chainId'])
         txes = txe.serialize()
         gas_price = strip_0x(txes['gasPrice'])
+        gas_price = compact(gas_price)
         gas = strip_0x(txes['gas'])
+        gas = compact(gas)
         return {
             'from': tx['from'],
             'to': txes['to'],
-            'gasPrice': add_0x(compact(gas_price)),
-            'gas': add_0x(compact(gas)),
+            'gasPrice': add_0x(gas_price, compact_value=True),
+            'gas': add_0x(gas, compact_value=True),
             'data': txes['data'],
                 }
 
@@ -523,7 +525,7 @@ class TxResult(BaseTxResult, Src):
     def apply_src(self, v):
         self.contract = None
 
-        super(TxResult, self).apply_src(v)
+        v = super(TxResult, self).apply_src(v)
 
         self.set_hash(v['transaction_hash'])
         try:
@@ -697,8 +699,8 @@ class Tx(BaseTx, Src):
         :returns: Wire format, in hex
         """
         if self.wire == None:
-            b = pack(self.src(), chain_spec)
-            self.wire = add_0x(b.hex())
+            b = pack(self.src, chain_spec)
+            self.set_wire(add_0x(b.hex()))
         return self.wire
 
 
@@ -747,13 +749,16 @@ input {}
         self.payload,
         )
 
-        if self.status != Status.PENDING:
+        status = Status.UNKNOWN.name
+        logg.debug('selfstatus {}'.format(self.status))
+        if self.result != None and self.result.status != Status.PENDING:
             s += """gas_used {}
 """.format(
-        self.gas_used,
+        self.result.fee_cost,
+            status = self.result.status.name
         )
 
-        s += 'status ' + self.status.name + '\n'
+        s += 'status ' + status + '\n'
 
         if self.block != None:
             s += """block_number {}
@@ -762,7 +767,7 @@ tx_index {}
 """.format(
         self.block.number,
         self.block.hash,
-        self.tx_index,
+        self.result.tx_index,
         )
 
 
@@ -775,7 +780,7 @@ tx_index {}
         if self.wire != None:
             s += """src {}
 """.format(
-        self.wire,
+        str(self.wire),
         )
 
         return s
